@@ -1,9 +1,7 @@
-# TODO:   Print methods specific for taxlist objects
-# 
-# Author: Miguel Alvarez
-################################################################################
-
-# Module for a general summary
+#' Function producing the overview of whole object.
+#' 
+#' @keywords internal
+#' 
 overview_taxlist <- function(object, units, check_validity) {
     cat("object size:", format(object.size(object), units=units), sep=" ", "\n")
     if(check_validity)
@@ -39,7 +37,10 @@ overview_taxlist <- function(object, units, check_validity) {
     cat("\n")
 }
 
-# Module for single taxa
+#' Function producing the overview of single taxon concepts.
+#' 
+#' @keywords internal
+#' 
 overview_taxon <- function(object, ConceptID, display, maxsum, secundum=NULL) {
 	if(is.character(ConceptID)) {
 		if(ConceptID[1] == "all")
@@ -73,7 +74,8 @@ overview_taxon <- function(object, ConceptID, display, maxsum, secundum=NULL) {
     # display option
     display <- pmatch(display[1], c("name","author","both"))
     if(!display %in% c(1:3))
-        stop("non-valid value for 'display'")
+        stop(paste("Invalid value for 'display', use \"name\", \"author\"",
+						"or \"both\""))
     if(display == 1) display <- c("TaxonUsageID", "TaxonName")
     if(display == 2) display <- c("TaxonUsageID", "AuthorName")
     if(display == 3) display <- c("TaxonUsageID", "TaxonName", "AuthorName")
@@ -128,7 +130,67 @@ overview_taxon <- function(object, ConceptID, display, maxsum, secundum=NULL) {
     cat("------------------------------", "\n")
 }
 
-# Now set the method
+#' @name summary
+#' 
+#' @title Print overviews for taxlist Objects and their content
+#' 
+#' @description 
+#' A method to display either an overview of the content of
+#' [taxlist-class] objects or an overview of selected taxa.
+#' 
+#' @param object A [taxlist-class] object.
+#' @param ConceptID IDs of concepts to be displayed in the summary.
+#' @param units Character value indicating the units shown in the object's
+#'     allocated space.
+#' @param check_validity Logical value indicating whether the validity of
+#'     `object` should be checked or not.
+#' @param display Character value indicating the field to be displayed (see
+#'     details).
+#' @param maxsum Integer indicating the maximum number of displayed taxa.
+#' @param secundum A character value indicating the column from slot`taxonViews`
+#'     to be displayed in the summary.
+#' @param ... Further arguments passed to or from another methods.
+#' 
+#' @details 
+#' A general overview indicating number of names, concepts and taxon views
+#' included in [taxlist-class] objects.
+#' If argument `ConceptID` is a vector with concept IDs or names to be matched
+#' by [grepl()], then a display of all names included in each concept will be
+#' produced.
+#' Alternative you can use `taxon="all"` in order to get the listing of names
+#' for all concepts included in the object (truncated to the input number of
+#' `maxsum`).
+#' 
+#' For summaries applied to concepts, there are three alternative displays of
+#' names using the argument `display`.
+#' Use `display="name"` to show the value `TaxonName`, `display="author"` to
+#' show the value `AuthorName` or `display="both"` to show both values.
+#' Such values are taken from slot `taxonNames`.
+#' 
+#' For big objects it will be recommended to set `units="Mb"` (see also
+#' [object.size()] for further alternatives).
+#' 
+#' @author Miguel Alvarez \email{kamapu78@@gmail.com}
+#' 
+#' @seealso [taxlist-class]
+#' 
+#' @examples 
+#' ## summary of the object
+#' summary(Easplist, units="Mb")
+#' 
+#' ## summary for two taxa
+#' summary(Easplist, c(51128,51140))
+#' 
+#' ## summary for a name
+#' summary(Easplist, "Acmella")
+#' 
+#' ## summary for the first 10 taxa
+#' summary(Easplist, "all", maxsum=10)
+#' 
+#' @aliases summary,taxlist-method
+#' 
+#' @exportMethod summary
+#' 
 setMethod("summary", signature(object="taxlist"),
         function(object, ConceptID, units="Kb", check_validity=TRUE,
                 display="both", maxsum=5, secundum=NULL, ...) {
